@@ -3,8 +3,7 @@
 # @param a non-evaluated expression.
 # @return logical - TRUE if expr is of "first-argument" type, FALSE otherwise.
 # @author Stefan Milton Bache and Hadley Wickham
-is_first <- function(expr)
-{
+is_first <- function(expr) {
   !any(vapply(expr[-1L], identical, logical(1L), quote(.)))
 }
 
@@ -13,7 +12,6 @@ is_first <- function(expr)
 # @param a an expression which passes \code{is_first}
 # @return an expression prepared for functional sequence construction.
 # @author Stefan Milton Bache and Hadley Wickham
-prepare_first <- function(expr)
-{
+prepare_first <- function(expr) {
   as.call(c(expr[[1L]], quote(.), as.list(expr[-1L])))
 }
