@@ -3,8 +3,7 @@
 # @param a non-evaluated expression.
 # @return logical - TRUE if expr represents a function, FALSE otherwise.
 # @author Stefan Milton Bache and Hadley Wickham
-is_function <- function(expr)
-{
+is_function <- function(expr) {
   is.symbol(expr) || is.function(expr)
 }
 
@@ -13,7 +12,6 @@ is_function <- function(expr)
 # @param a an expression which passes \code{is_function}
 # @return an expression prepared for functional sequence construction.
 # @author Stefan Milton Bache and Hadley Wickham
-prepare_function <- function(f)
-{
+prepare_function <- function(f) {
   as.call(list(f, quote(.)))
 }
