@@ -34,20 +34,20 @@
 #' library(dplyr)
 #' df <- data.frame(x = sample(10, 5, rep = TRUE),
 #'                  y = sample(10, 5, rep = TRUE)) %>%
-#'   at_mutate(example="yes",
-#'             package="dplyr", 
+#'   at_mutate(example = "yes",
+#'             package = "dplyr", 
 #'             class = c("my_tbl", "data.frame"))
 #' tribe(df)
 #' 
 #' # Attributes just created are lost when the object 
 #' # passes through dplyr verbs
-#' tribe(df %>% mutate(z=3))
+#' tribe(df %>% mutate(z = 3))
 #' 
 #' # With the pipe '%@>%', most attributes are kept
-#' tribe(df %@>% mutate(z=3))
+#' tribe(df %@>% mutate(z = 3))
 #' 
 #' # One can create a new pipe to adjust attributes propagation settings
-#' "%newpipe>%" <- make_pipe(propagate="none", keep_also = "example")
+#' "%newpipe>%" <- make_pipe(propagate = "none", keep_also = "example")
 #' tribe(df %newpipe>% mutate(z=3))
 #' 
 make_pipe <- 
@@ -61,7 +61,7 @@ function(propagate, # = getOption("propagate")
     parent <- parent.frame()
     
     # the environment in which to evaluate pipeline
-    env    <- new.env(parent = parent)
+    env <- new.env(parent = parent)
 
     # split the pipeline/chain into its parts.
     chain_parts <- split_chain(match.call(), env = env)
@@ -135,7 +135,7 @@ function(propagate, # = getOption("propagate")
     }
   }
   class(pipe) <- c("pipe", "function")
-  return(pipe)
+  pipe
 }
 
 
